Module stream

Module stream 

Gantry streaming protocol

This module contains data types and traits for use with Gantry’s module streaming functionality. Gantry separates the streaming of a module’s raw bytes from the management of a module’s metadata. The following operations are available for streaming:

  • stream_put - Send the raw bytes for a module to Gantry, corresponding to a specific public key+revision pair
  • stream_get - Retrieve the raw bytes for a module to Gantry, corresponding to a specific public key+revision pair

Structs

ChunkAck
Acknowledgement of a single chunk
DownloadRequest
A request to download a file from Gantry
FileChunk
A single chunk of a file
TransferAck
UploadRequest
A request to upload a file to Gantry

Statics

SUBJECT_STREAM_DOWNLOAD
SUBJECT_STREAM_DOWNLOAD_PREFIX
SUBJECT_STREAM_UPLOAD
SUBJECT_STREAM_UPLOAD_PREFIX