Gantry streaming protocol
This module contains data types and traits for use with Gantry’s module streaming functionality. Gantry separates the streaming of a module’s raw bytes from the management of a module’s metadata. The following operations are available for streaming:
stream_put- Send the raw bytes for a module to Gantry, corresponding to a specific public key+revision pairstream_get- Retrieve the raw bytes for a module to Gantry, corresponding to a specific public key+revision pair
Structs
- Chunk
Ack - Acknowledgement of a single chunk
- Download
Request - A request to download a file from Gantry
- File
Chunk - A single chunk of a file
- Transfer
Ack - Upload
Request - A request to upload a file to Gantry